@@ -13,19 +13,19 @@ if [ -z $2 ]; then
 else
 	IFACE=$2
 fi
-IFCHECK=$(/sbin/ifconfig $IFACE|grep ask|awk '{print $2}'|cut -d ':' -f2)
+IFCHECK=$(/sbin/ifconfig $IFACE|awk '/netmask/{print $2; exit}')
 # Define where we should store last IP
-IPFILE="/tmp/ddupip"
+IPFILE="/var/db/ddup.ip"
 IPCHECK=$(cat $IPFILE)
+FILECHECK=$(find $IPFILE -mtime -25)
+
 # Define path to ddup and ddup arguments (except --host)
-DDUP_PATH="/usr/local/sbin/ddup"
+DDUP_PATH="%%PREFIX%%/sbin/ddup"
 DDUP_ARGS="--debug"
 
-
-if [ "$IFCHECK" = "$IPCHECK" ]; then
+if [ "$IFCHECK" = "$IPCHECK" ] && [ "x$FILECHECK" != x ]; then
 	echo "looks like we are still the same ip"
 else
 	$DDUP_PATH --host $HOST $DDUP_ARGS
 	echo "$IFCHECK" > $IPFILE
 fi
-
